<?php
/*
Plugin Name: WPnet.pl FadeThis plugin
Plugin URI: http://wpnet.pl/blog/wtyczki/wtyczka-wpnet-pl-fadethis/
Version: 1.0
Author: wpnet.pl
Author URI: http://wpnet.pl
License: GPL2
*/

// Make sure we don't expose any info if called directly
if ( !function_exists( 'add_action' ) ) {
	exit;
}

/**
 * Load plugin textdomain.
 *
 * @since 1.0.0
 */
function wpnet_fadethis_load_textdomain() {
	load_plugin_textdomain( 'wpnet-fadethis', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
}
add_action( 'init', 'wpnet_fadethis_load_textdomain' );

/**
 * Enqueue scripts.
 */
function wpnet_fadethis_scripts() {
	wp_register_script( 'jquery-fadethis',  plugin_dir_url( __FILE__ ) . 'jquery.fadethis.min.js' );
    wp_enqueue_script( 'jquery-fadethis' );

	wp_register_script( 'jquery-easing',  plugin_dir_url( __FILE__ ) . 'jquery.easing.js' );
    wp_enqueue_script( 'jquery-easing' );
}
add_action( 'wp_enqueue_scripts', 'wpnet_fadethis_scripts' );

function wpnet_fadethis_admin_init(){
	register_setting('wpnet_fadethis_options', 'wpnet_fadethis_speed', 'intval');
	register_setting('wpnet_fadethis_options', 'wpnet_fadethis_distance', 'intval');
	register_setting('wpnet_fadethis_options', 'wpnet_fadethis_offset', 'intval');
	register_setting('wpnet_fadethis_options', 'wpnet_fadethis_reverse');
	register_setting('wpnet_fadethis_options', 'wpnet_fadethis_easing');
}
add_action( 'admin_init', 'wpnet_fadethis_admin_init');

function wpnet_fadethis_setup_options(){
	update_option("wpnet_fadethis_speed", "500");
	update_option("wpnet_fadethis_distance", "50");
	update_option("wpnet_fadethis_offset", "0");
	update_option("wpnet_fadethis_reverse", "on");
	update_option("wpnet_fadethis_easing", "swing");
}
register_activation_hook( __FILE__, 'wpnet_fadethis_setup_options' );

function wpnet_fadethis_js_head(){?>
	<script>

	function prependClass(sel, strClass) {
		var $el = jQuery(sel);
		var classes = $el.attr('class');
		classes = strClass +' ' +classes;
		$el.attr('class', classes);
	}

	jQuery(document).ready(function() {
		prependClass('.aligncenter', 'slide-bottom');
		prependClass('.alignleft', 'slide-left');
		prependClass('.alignright', 'slide-right');

		jQuery(window).fadeThis({
            easing: '<?php echo get_option('wpnet_fadethis_easing'); ?>',
			speed: <?php echo get_option('wpnet_fadethis_speed'); ?>,
			distance: <?php echo get_option('wpnet_fadethis_distance'); ?>,
			offset: <?php echo get_option('wpnet_fadethis_offset'); ?>,
			reverse: <?php if( get_option('wpnet_fadethis_reverse') ) echo 'true'; else echo 'false'; ?>,
		});
	});
	</script>
<?php
}
add_action( 'wp_head', 'wpnet_fadethis_js_head' );

function wpnet_fadethis_settings_page(){
	?>
	<div class="wrap">
		<?php screen_icon(); ?>
		<h2><?php _e('WPnet.pl FadeThis', 'wpnet-fadethis'); ?></h2>
		<form action="options.php" method="post" id="wpnet-fadethis-options-form">
			<?php settings_fields('wpnet_fadethis_options'); ?>

			<table>
				<tr>
					<td>
						<label for="wpnet_fadethis_speed"><?php _e('Speed:', 'wpnet-fadethis'); ?></label>
					</td>
					<td>
						<input type="text" name="wpnet_fadethis_speed" id="wpnet_fadethis_speed" value="<?php echo get_option('wpnet_fadethis_speed'); ?>"/>
					</td>
					<td>
						<?php _e('Animation speed in milliseconds.', 'wpnet-fadethis'); ?>
					</td>
				</tr>
				<tr>
					<td>
						<label for="wpnet_fadethis_distance"><?php _e('Distance:', 'wpnet-fadethis'); ?></label>
					</td>
					<td>
						<input type="text" name="wpnet_fadethis_distance" id="wpnet_fadethis_distance" value="<?php echo get_option('wpnet_fadethis_distance'); ?>"/>
					</td>
					<td>
						<?php _e('Element distance to its emplacement, before animation.', 'wpnet-fadethis'); ?>
					</td>
				</tr>
				<tr>
					<td>
						<label for="wpnet_fadethis_offset"><?php _e('Offset:', 'wpnet-fadethis'); ?></label>
					</td>
					<td>
						<input type="text" name="wpnet_fadethis_offset" id="wpnet_fadethis_offset" value="<?php echo get_option('wpnet_fadethis_offset'); ?>"/>
					</td>
					<td>
						<?php _e('Scroll offset, allowing to fire fading a little after or before the element appear.', 'wpnet-fadethis'); ?>
					</td>
				</tr>
				<tr>
					<td>
						<label for="wpnet_fadethis_reverse"><?php _e('Reverse:', 'wpnet-fadethis'); ?></label>
					</td>
					<td>
						<input type="checkbox" name="wpnet_fadethis_reverse" id="wpnet_fadethis_reverse" <?php if ( get_option('wpnet_fadethis_reverse') ) echo 'checked="checked"'; ?>/>
					</td>
					<td>
						<?php _e('Make element disappear again when scrolled out, and fade again when scrolled in. Uncheck this if you want elements to stay on page after they appear once.', 'wpnet-fadethis'); ?>
					</td>
				</tr>
				<tr>
					<td>
						<label for="wpnet_fadethis_easing"><?php _e('Easing:', 'wpnet-fadethis'); ?></label>
					</td>
					<td>
						<select name="wpnet_fadethis_easing" id="wpnet_fadethis_easing">
						<?php
						$easing_effects_array = array( 'linear', 'swing', 'easeInQuad', 'easeOutQuad', 'easeInOutQuad', 'easeInCubic', 'easeOutCubic', 'easeInOutCubic', 'easeInQuart', 'easeOutQuart', 'easeInOutQuart', 'easeInQuint', 'easeOutQuint', 'easeInOutQuint', 'easeInExpo', 'easeOutExpo', 'easeInOutExpo', 'easeInSine', 'easeOutSine', 'easeInOutSine', 'easeInCirc', 'easeOutCirc', 'easeInOutCirc', 'easeInElastic', 'easeOutElastic', 'easeInOutElastic', 'easeInBack', 'easeOutBack', 'easeInOutBack', 'easeInBounce', 'easeOutBounce', 'easeInOutBounce' );

						foreach ($easing_effects_array as $easing_effect) {
							echo '<option value="' . $easing_effect . '"';
							if ( get_option('wpnet_fadethis_easing') == $easing_effect ) echo 'selected="selected"';
							echo '>' . $easing_effect . '</option>';
						} ?>
						</select><br/>

					</td>
					<td>
						<?php _e('Animation easing.', 'wpnet-fadethis'); ?>	<a href="http://api.jqueryui.com/easings/" target="_blank"><?php _e('See easing effects', 'wpnet-fadethis'); ?></a>
					</td>
				</tr>
				<tr>
					<td>
					</td>
					<td>
						<input type="submit" name="submit" id="submit" class="button-primary" value="<?php _e('Save Changes'); ?>" />
					</td>
					<td>
					</td>
				</tr>
			</table>
		</form>
	</div>
	<div class="wrap">
		<form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_top">
			<input type="hidden" name="cmd" value="_s-xclick">
			<input type="hidden" name="hosted_button_id" value="BEHH8245DZBMY">
			<input type="image" src="https://www.paypalobjects.com/pl_PL/PL/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="PayPal — Płać wygodnie i bezpiecznie">
			<img alt="" border="0" src="https://www.paypalobjects.com/pl_PL/i/scr/pixel.gif" width="1" height="1">
		</form>
	</div>
	<?php
}

function wpnet_fadethis_settings_menu(){
	add_options_page(__('WPnet.pl FadeThis', 'wpnet-fadethis'),__('WPnet.pl FadeThis', 'wpnet-fadethis'),'manage_options',__FILE__,'wpnet_fadethis_settings_page');
}
add_action('admin_menu', 'wpnet_fadethis_settings_menu');

?>